

extern int PL_argc;
extern char **PL_argv;

void args2argv(void);
void free_PL_argv(void);
